@@ -81,6 +81,18 @@ ImageView::~ImageView() {
   }
 }
 
+QGraphicsItem* ImageView::imageGraphicsItem() const {
+  if(!items().isEmpty()) {
+    return (items().constLast()); // the lowermost item
+  }
+  return nullptr;
+}
+
+QGraphicsItem* ImageView::outlineGraphicsItem() const {
+  return outlineItem_;
+}
+
+
 void ImageView::onFileDropped(const QString file) {
     Q_EMIT fileDropped(file);
 }
@@ -113,19 +125,25 @@ void ImageView::mouseDoubleClickEvent(QMouseEvent* event) {
 }
 
 void ImageView::mousePressEvent(QMouseEvent * event) {
-  if (currentTool == ToolNone) {
+  if(currentTool == ToolNone) {
     QGraphicsView::mousePressEvent(event);
-    if(cursorTimer_) cursorTimer_->stop();
-  } else {
+    if(cursorTimer_) {
+      cursorTimer_->stop();
+    }
+  }
+  else {
     startPoint = mapToScene(event->pos()).toPoint();
   }
 }
 
 void ImageView::mouseReleaseEvent(QMouseEvent* event) {
-  if (currentTool == ToolNone) {
+  if(currentTool == ToolNone) {
     QGraphicsView::mouseReleaseEvent(event);
-    if(cursorTimer_) cursorTimer_->start(CURSOR_HIDE_DELY);
-  } else if (!image_.isNull()) {
+    if(cursorTimer_) {
+      cursorTimer_->start(CURSOR_HIDE_DELY);
+    }
+  }
+  else if(!image_.isNull()) {
     QPoint endPoint = mapToScene(event->pos()).toPoint();
 
     QPainter painter(&image_);
@@ -137,10 +155,14 @@ void ImageView::mouseReleaseEvent(QMouseEvent* event) {
       drawArrow(painter, startPoint, endPoint, M_PI / 8, 25);
       break;
     case ToolRectangle:
+      // Draw the rectangle in the image and scene at the same time
       painter.drawRect(QRect(startPoint, endPoint));
+      annotations.append(scene_->addRect(QRect(startPoint, endPoint), painter.pen()));
       break;
     case ToolCircle:
+      // Draw the circle in the image and scene at the same time
       painter.drawEllipse(QRect(startPoint, endPoint));
+      annotations.append(scene_->addEllipse(QRect(startPoint, endPoint), painter.pen()));
       break;
     case ToolNumber:
     {
@@ -161,15 +183,24 @@ void ImageView::mouseReleaseEvent(QMouseEvent* event) {
                         textRect.top() + (textRect.height() / 2 - radius),
                         radius * 2, radius * 2);
 
-      // Draw the path
+      // Draw the path in the image
       QPainterPath path;
       path.addEllipse(circleRect);
       painter.fillPath(path, Qt::red);
       painter.drawPath(path);
+      // Draw the path in the sence
+      annotations.append(scene_->addPath(path, painter.pen(), QBrush(Qt::red)));
 
-      // Draw the text
+      // Draw the text in the image
       painter.setPen(Qt::white);
       painter.drawText(textRect, Qt::AlignCenter, text);
+      // Draw the text in the sence
+      QGraphicsSimpleTextItem* textItem = new QGraphicsSimpleTextItem(text);
+      textItem->setFont(font);
+      textItem->setBrush(Qt::white);
+      textItem->setPos(textRect.topLeft());
+      scene_->addItem(textItem);
+      annotations.append(textItem);
 
       break;
     }
@@ -251,17 +282,19 @@ void ImageView::zoomOriginal() {
 
 void ImageView::drawOutline() {
   QColor col = QColor(Qt::black);
-  if (qGray(backgroundBrush().color().rgb()) < GRAY)
+  if(qGray(backgroundBrush().color().rgb()) < GRAY) {
     col = QColor(Qt::white);
+  }
   QPen outline(col, 1, Qt::DashLine);
   outline.setCosmetic(true);
   outlineItem_->setPen(outline);
   outlineItem_->setBrush(Qt::NoBrush);
   outlineItem_->setVisible(showOutline_);
-  outlineItem_->setZValue(1);
+  outlineItem_->setZValue(1); // to be drawn on top of all other items
 }
 
 void ImageView::setImage(const QImage& image, bool show) {
+  removeAnnotations();
   if(show && (gifMovie_ || isSVG)) { // a gif animation or SVG file was shown before
     scene_->clear();
     isSVG = false;
@@ -312,6 +345,7 @@ void ImageView::setImage(const QImage& image, bool show) {
 }
 
 void ImageView::setGifAnimation(const QString& fileName) {
+  removeAnnotations();
   /* the built-in gif reader gives the first frame, which won't
      be shown but is used for tracking position and dimensions */
   image_ = QImage(fileName);
@@ -361,6 +395,7 @@ void ImageView::setGifAnimation(const QString& fileName) {
 }
 
 void ImageView::setSVG(const QString& fileName) {
+  removeAnnotations();
   image_ = QImage(fileName); // for tracking position and dimensions
   if(image_.isNull()) {
     if(imageItem_) {
@@ -378,7 +413,7 @@ void ImageView::setSVG(const QString& fileName) {
     imageItem_ = nullptr;
     isSVG = true;
     QGraphicsSvgItem *svgItem = new QGraphicsSvgItem(fileName);
-    svgItem->setScale(1 / qApp->devicePixelRatio()); // show scg with its real size
+    svgItem->setScale(1 / qApp->devicePixelRatio()); // show svg with its real size
     scene_->addItem(svgItem);
     QRectF r(svgItem->boundingRect());
     r.setBottomRight(r.bottomRight() / qApp->devicePixelRatio());
@@ -418,8 +453,9 @@ void ImageView::showOutline(bool show) {
 void ImageView::updateOutline() {
   if(outlineItem_) {
     QColor col = QColor(Qt::black);
-    if (qGray(backgroundBrush().color().rgb()) < GRAY)
+    if(qGray(backgroundBrush().color().rgb()) < GRAY) {
       col = QColor(Qt::white);
+    }
     QPen outline = outlineItem_->pen();
     outline.setColor(col);
     outlineItem_->setPen(outline);
@@ -446,8 +482,9 @@ void ImageView::paintEvent(QPaintEvent* event) {
         // outline
         if(showOutline_) {
             QColor col = QColor(Qt::black);
-            if (qGray(backgroundBrush().color().rgb()) < GRAY)
+            if(qGray(backgroundBrush().color().rgb()) < GRAY) {
               col = QColor(Qt::white);
+            }
             QPen outline(col, 1, Qt::DashLine);
             painter.setPen(outline);
             painter.drawRect(viewportImageRect);
@@ -511,8 +548,9 @@ void ImageView::generateCache() {
 
   // If the original image has a color table, also use it for the subImage
   QVector<QRgb> colorTable = image_.colorTable();
-  if (!colorTable.empty())
+  if(!colorTable.empty()) {
     subImage.setColorTable(colorTable);
+  }
 
   // QImage scaled = subImage.scaled(subRect.width() * scaleFactor_, subRect.height() * scaleFactor_, Qt::KeepAspectRatio, Qt::SmoothTransformation);
   QImage scaled = subImage.scaled(cachedRect_.size() * qApp->devicePixelRatio(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
@@ -548,15 +586,17 @@ void ImageView::hideCursor(bool enable) {
     cursorTimer_ = new QTimer(this);
     cursorTimer_->setSingleShot(true);
     connect(cursorTimer_, &QTimer::timeout, this, &ImageView::blankCursor);
-    if(viewport()->cursor().shape() == Qt::OpenHandCursor)
-        cursorTimer_->start(CURSOR_HIDE_DELY);
+    if(viewport()->cursor().shape() == Qt::OpenHandCursor) {
+      cursorTimer_->start(CURSOR_HIDE_DELY);
+    }
   }
-  else if (cursorTimer_) {
+  else if(cursorTimer_) {
     cursorTimer_->stop();
     delete cursorTimer_;
     cursorTimer_ = nullptr;
-    if(viewport()->cursor().shape() == Qt::BlankCursor)
-        viewport()->setCursor(Qt::OpenHandCursor);
+    if(viewport()->cursor().shape() == Qt::BlankCursor) {
+      viewport()->setCursor(Qt::OpenHandCursor);
+    }
   }
 }
 
@@ -571,10 +611,12 @@ void ImageView::drawArrow(QPainter &painter,
                           const QPoint &start,
                           const QPoint &end,
                           qreal tipAngle,
-                          int tipLen) const
+                          int tipLen)
 {
-  // Draw the line
+  // Draw the line in the inmage
   painter.drawLine(start, end);
+  // Draw the line in the scene
+  annotations.append(scene_->addLine(QLine(start, end), painter.pen()));
 
   // Calculate the angle of the line
   QPoint delta = end - start;
@@ -590,9 +632,24 @@ void ImageView::drawArrow(QPainter &painter,
     static_cast<int>(qCos(angle - tipAngle) * tipLen)
   );
 
-  // Draw the two lines
+  // Draw the two lines in the image
   painter.drawLine(end, end + tip1);
   painter.drawLine(end, end + tip2);
+  // Draw the two lines in the scene
+  annotations.append(scene_->addLine(QLine(end, end+tip1), painter.pen()));
+  annotations.append(scene_->addLine(QLine(end, end+tip2), painter.pen()));
+}
+
+void ImageView::removeAnnotations() {
+  if(!annotations.isEmpty()) {
+    if(!scene_->items().isEmpty()) { // WARNING: This is not enough to guard against dangling pointers.
+      for(const auto& annotation : qAsConst(annotations)) {
+        scene_->removeItem(annotation);
+      }
+      qDeleteAll(annotations.begin(), annotations.end());
+    }
+    annotations.clear();
+  }
 }
 
 } // namespace LxImage
