@@ -51,6 +51,7 @@
 #include <libfm-qt/folderitemdelegate.h>
 
 #include "mrumenu.h"
+#include "resizeimagedialog.h"
 #include "upload/uploaddialog.h"
 
 using namespace LxImage;
@@ -289,7 +290,7 @@ void MainWindow::openImageFile(const QString& fileName) {
     if(path == folderPath_)
       return;
 
-    QList<QByteArray> formats = QImageReader::supportedImageFormats();
+    const QList<QByteArray> formats = QImageReader::supportedImageFormats();
     QStringList formatsFilters;
     for (const QByteArray& format: formats)
       formatsFilters << QStringLiteral("*.") + QString::fromUtf8(format);
@@ -681,17 +682,22 @@ void MainWindow::updateUI() {
     if(loadJob_) { // if loading is in progress
       title = tr("[*]%1 (Loading...) - Image Viewer")
                 .arg(QString::fromUtf8(dispName.get()));
+      ui.statusBar->setText();
     }
     else {
       if(image_.isNull()) {
         title = tr("[*]%1 (Failed to Load) - Image Viewer")
                   .arg(QString::fromUtf8(dispName.get()));
+        ui.statusBar->setText();
       }
       else {
+        const QString filePath = QString::fromUtf8(dispName.get());
         title = tr("[*]%1 (%2x%3) - Image Viewer")
-                  .arg(QString::fromUtf8(dispName.get()))
+                  .arg(filePath)
                   .arg(image_.width())
                   .arg(image_.height());
+        ui.statusBar->setText(QStringLiteral("%1×%2").arg(image_.width()).arg(image_.height()),
+                              filePath);
         if (!isVisible()) {
           /* Here we try to implement the following behavior as far as possible:
               (1) A minimum size of 400x400 is assumed;
@@ -709,8 +715,11 @@ void MainWindow::updateUI() {
           show();
           int scrollThickness = style()->pixelMetric(QStyle::PM_ScrollBarExtent);
           QSize newSize = size() + image_.size() - ui.view->size() + QSize(scrollThickness, scrollThickness);
-          const QScreen *primaryScreen = QGuiApplication::primaryScreen();
-          const QRect ag = primaryScreen ? primaryScreen->availableGeometry() : QRect();
+          QScreen *appScreen = QGuiApplication::screenAt(QCursor::pos());
+          if(appScreen == nullptr) {
+            appScreen = QGuiApplication::primaryScreen();
+          }
+          const QRect ag = appScreen ? appScreen->availableGeometry() : QRect();
           // since the window isn't decorated yet, we have to assume a max thickness for its frame
           QSize maxFrame = QSize(50, 100);
           if(newSize.width() > ag.width() - maxFrame.width()
@@ -730,6 +739,7 @@ void MainWindow::updateUI() {
   }
   else {
     title = tr("[*]Image Viewer");
+    ui.statusBar->setText();
   }
   setWindowTitle(title);
   setWindowModified(imageModified_);
@@ -813,35 +823,24 @@ void MainWindow::saveImage(const Fm::FilePath & filePath) {
   saveJob_ = new SaveImageJob(ui.view->image(), filePath);
   connect(saveJob_, &Fm::Job::finished, this, &MainWindow::onImageSaved);
   connect(saveJob_, &Fm::Job::error, this
-        , [] (const Fm::GErrorPtr & err, Fm::Job::ErrorSeverity /*severity*/, Fm::Job::ErrorAction & /*response*/)
+        , [this] (const Fm::GErrorPtr & err, Fm::Job::ErrorSeverity severity, Fm::Job::ErrorAction & /*response*/)
         {
           // TODO: show a info bar?
-          qWarning().noquote() << "lximage-qt:" << err.message();
+          if(severity > Fm::Job::ErrorSeverity::MODERATE) {
+            QMessageBox::critical(this, QObject::tr("Error"), err.message());
+          }
+          else {
+            qWarning().noquote() << "lximage-qt:" << err.message();
+          }
         }
       , Qt::BlockingQueuedConnection);
   saveJob_->runAsync();
   // FIXME: add a cancel button to the UI? update status bar?
 }
 
-QGraphicsItem* MainWindow::getImageGraphicsItem() {
-  if(!ui.view->items().isEmpty()) {
-    return (ui.view->items().size() > 1
-            ? ui.view->items().at(1) // the first item is outline (the uppermost item)
-            : ui.view->items().at(0));
-  }
-  return nullptr;
-}
-
-QGraphicsItem* MainWindow::getOutlineGraphicsItem() {
-  if(ui.view->items().size() > 1) {
-    return ui.view->items().at(0);
-  }
-  return nullptr;
-}
-
 void MainWindow::on_actionRotateClockwise_triggered() {
-  QGraphicsItem *imageItem = getImageGraphicsItem();
-  bool isGifOrSvg (imageItem->isWidget() // we have gif animation
+  QGraphicsItem *imageItem = ui.view->imageGraphicsItem();
+  bool isGifOrSvg ((imageItem && imageItem->isWidget()) // we have gif animation
                    || dynamic_cast<QGraphicsSvgItem*>(imageItem)); // an SVG image;
   if(!image_.isNull()) {
     QTransform transform;
@@ -862,7 +861,7 @@ void MainWindow::on_actionRotateClockwise_triggered() {
     imageItem->setTransform(transform, false);
     imageItem->setTransform(prevTrans, true);
     // apply transformations to the outline item too
-    if(QGraphicsItem *outlineItem = getOutlineGraphicsItem()){
+    if(QGraphicsItem *outlineItem = ui.view->outlineGraphicsItem()){
       outlineItem->setTransform(transform, false);
       outlineItem->setTransform(prevTrans, true);
     }
@@ -870,8 +869,8 @@ void MainWindow::on_actionRotateClockwise_triggered() {
 }
 
 void MainWindow::on_actionRotateCounterclockwise_triggered() {
-  QGraphicsItem *imageItem = getImageGraphicsItem();
-  bool isGifOrSvg (imageItem->isWidget()
+  QGraphicsItem *imageItem = ui.view->imageGraphicsItem();
+  bool isGifOrSvg ((imageItem && imageItem->isWidget())
                    || dynamic_cast<QGraphicsSvgItem*>(imageItem));
   if(!image_.isNull()) {
     QTransform transform;
@@ -888,7 +887,7 @@ void MainWindow::on_actionRotateCounterclockwise_triggered() {
     QTransform prevTrans = imageItem->transform();
     imageItem->setTransform(transform, false);
     imageItem->setTransform(prevTrans, true);
-    if(QGraphicsItem *outlineItem = getOutlineGraphicsItem()){
+    if(QGraphicsItem *outlineItem = ui.view->outlineGraphicsItem()){
       outlineItem->setTransform(transform, false);
       outlineItem->setTransform(prevTrans, true);
     }
@@ -909,6 +908,13 @@ void MainWindow::on_actionCopy_triggered() {
   clipboard->setImage(copiedImage);
 }
 
+void MainWindow::on_actionCopyPath_triggered() {
+  if(currentFile_) {
+    const Fm::CStrPtr dispName = currentFile_.displayName();
+    QApplication::clipboard()->setText(QString::fromUtf8(dispName.get()));
+  }
+}
+
 void MainWindow::on_actionPaste_triggered() {
   QClipboard *clipboard = QApplication::clipboard();
   QImage image = clipboard->image();
@@ -948,7 +954,7 @@ void MainWindow::on_actionUpload_triggered()
 
 void MainWindow::on_actionFlipVertical_triggered() {
   bool hasQGraphicsItem(false);
-  if(QGraphicsItem *imageItem = getImageGraphicsItem()) {
+  if(QGraphicsItem *imageItem = ui.view->imageGraphicsItem()) {
     hasQGraphicsItem = true;
     QTransform transform;
     transform.scale(1, -1);
@@ -956,7 +962,7 @@ void MainWindow::on_actionFlipVertical_triggered() {
     QTransform prevTrans = imageItem->transform();
     imageItem->setTransform(transform, false);
     imageItem->setTransform(prevTrans, true);
-    if(QGraphicsItem *outlineItem = getOutlineGraphicsItem()){
+    if(QGraphicsItem *outlineItem = ui.view->outlineGraphicsItem()){
       outlineItem->setTransform(transform, false);
       outlineItem->setTransform(prevTrans, true);
     }
@@ -970,7 +976,7 @@ void MainWindow::on_actionFlipVertical_triggered() {
 
 void MainWindow::on_actionFlipHorizontal_triggered() {
   bool hasQGraphicsItem(false);
-  if(QGraphicsItem *imageItem = getImageGraphicsItem()) {
+  if(QGraphicsItem *imageItem = ui.view->imageGraphicsItem()) {
     hasQGraphicsItem = true;
     QTransform transform;
     transform.scale(-1, 1);
@@ -978,7 +984,7 @@ void MainWindow::on_actionFlipHorizontal_triggered() {
     QTransform prevTrans = imageItem->transform();
     imageItem->setTransform(transform, false);
     imageItem->setTransform(prevTrans, true);
-    if(QGraphicsItem *outlineItem = getOutlineGraphicsItem()){
+    if(QGraphicsItem *outlineItem = ui.view->outlineGraphicsItem()){
       outlineItem->setTransform(transform, false);
       outlineItem->setTransform(prevTrans, true);
     }
@@ -990,6 +996,54 @@ void MainWindow::on_actionFlipHorizontal_triggered() {
   }
 }
 
+void MainWindow::on_actionResize_triggered() {
+  if(image_.isNull()) {
+    return;
+  }
+  QGraphicsItem *imageItem = ui.view->imageGraphicsItem();
+  bool isSVG(dynamic_cast<QGraphicsSvgItem*>(imageItem));
+  bool isGifOrSvg(isSVG || (imageItem && imageItem->isWidget()));
+  QSize imgSize(image_.size());
+  ResizeImageDialog *dialog = new ResizeImageDialog(this);
+  dialog->setOriginalSize(image_.size());
+  if(dialog->exec() == QDialog::Accepted) {
+    QSize newSize = dialog->scaledSize();
+    if(!isSVG) { // with SVG, we get a sharp image below
+      image_ = image_.scaled(newSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+      ui.view->setImage(image_, isGifOrSvg ? false : true);
+    }
+    if(isGifOrSvg) {
+      qreal sx = static_cast<qreal>(newSize.width()) / imgSize.width();
+      qreal sy = static_cast<qreal>(newSize.height()) / imgSize.height();
+      QTransform transform;
+      transform.scale(sx, sy);
+      QTransform prevTrans = imageItem->transform();
+      imageItem->setTransform(transform, false);
+      imageItem->setTransform(prevTrans, true);
+      if(QGraphicsItem *outlineItem = ui.view->outlineGraphicsItem()) {
+        outlineItem->setTransform(transform, false);
+        outlineItem->setTransform(prevTrans, true);
+      }
+
+      if(isSVG) {
+        // create and set a sharp scaled image with SVG
+        QPixmap pixmap(newSize);
+        pixmap.fill(Qt::transparent);
+        QPainter painter(&pixmap);
+        painter.setTransform(imageItem->transform());
+        painter.setRenderHint(QPainter::Antialiasing);
+        QStyleOptionGraphicsItem opt;
+        imageItem->paint(&painter, &opt);
+        image_ = pixmap.toImage();
+        ui.view->setImage(image_, false);
+      }
+    }
+
+    setModified(true);
+  }
+  dialog->deleteLater();
+}
+
 void MainWindow::setModified(bool modified) {
   imageModified_ = modified;
   updateUI();
@@ -1182,7 +1236,8 @@ void MainWindow::setShowExifData(bool show) {
     exifDataContentTable_->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
     // Write the EXIF Data to the table
-    for (const QString& key : exifData_.keys()) {
+    const auto keys =exifData_.keys();
+    for (const QString& key : keys) {
       int rowCount = exifDataContentTable_->rowCount();
 
       exifDataContentTable_->insertRow(rowCount);
